/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: cmi@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: BlacklistFilter.java 2122 2008-09-27 09:41:35Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.cmi.controller.server.filter;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.ow2.cmi.controller.server.ServerClusterViewManager;
import org.ow2.cmi.reference.CMIReference;

/**
 * An universal filter to discard blacklisted server.
 * @author Loris Bouzonnet
 */
public class BlacklistFilter extends UniversalFilter {

    /**
     * The manager to retrieve load factors.
     */
    private final ServerClusterViewManager clusterViewManager;

    /**
     * @param clusterViewManager
     */
    public BlacklistFilter(final ServerClusterViewManager clusterViewManager) {
        this.clusterViewManager = clusterViewManager;
    }

    public List<CMIReference> choose(final Collection<CMIReference> loadBalanceables) {
        List<CMIReference> availables = new ArrayList<CMIReference>();
        for(CMIReference loadBalanceable : loadBalanceables) {
            if(!clusterViewManager.isServerBlackListed(loadBalanceable.getServerRef())) {
                availables.add(loadBalanceable);
            }
        }
        return availables;
    }

}
